@@ -15,7 +15,7 @@ def file_name(key):
 
 
 def folder_name(key):
-    return os.path.basename(os.path.normpath(key))
+    return os.path.basename(os.path.normpath(key)) + "/"
 
 
 def file_size(key):
